@@ -1122,10 +1122,17 @@ class AfsHgIncomeDivide(BaseModelTimeAndDeleted):
     id = models.CharField("id", primary_key=True, max_length=40, default=get_uuid4_hex)
     order_id = models.IntegerField('订单ID', blank=True, null=True, db_index=True)
     aftersale_id = models.IntegerField('AFS ID', blank=True, null=True, db_index=True)
-    divide_payment_type = models.IntegerField('营业外收入分配支付类型', blank=True, null=True, db_index=True)
+    divide_payment_type = models.CharField('营业外收入分配支付类型', max_length=10, blank=True, null=True, db_index=True)
     divide_amount = models.DecimalField("营业外收入分配金额", decimal_places=2, max_digits=12, blank=True, null=True, default=0)
     # pay_step_type 支付阶段(once全款/deposit定金/tail尾款)
     pay_step_type = models.CharField("支付阶段", max_length=24, choices=PayStepType.PAY_STEP_TYPE_CHOICES, default=PayStepType.ONCE, db_index=True)
     hgincome_type_id = models.IntegerField('hgincome Type ID', blank=True, null=True, db_index=True)
+    # 用来记录支付的详细信息：
+    #   优惠券：优惠券ID coupon_id
+    #   店内优惠券存 code
+    #   C券：用户 account_id
+    #   微信支付：用户 微信支付ID
+    #   支付宝支付：用户 支付宝支付ID
+    payment_num = models.CharField('支付号', max_length=50, blank=True, null=True)
     class Meta:
         app_label = 'sparrow_aftersale'
\ No newline at end of file
