@@ -83,6 +83,8 @@ class Distribute(BaseModelTimeAndDeleted):
     terminate_user_id = models.CharField("Terminate User ID", max_length=255, blank=True, null=True, db_index=True)
     # 发货单终结操作人名称
     terminate_user_name = models.CharField("Terminate User Name", max_length=255, blank=True, null=True)
+    # 发货单终结操作人角色
+    terminate_user_role = models.CharField("Terminate User Role", max_length=16, blank=True, null=True)
     # 导购留言
     guide_note = models.CharField('导购留言', max_length=16384, blank=True, null=True)
     # 出货时间
@@ -91,8 +93,10 @@ class Distribute(BaseModelTimeAndDeleted):
     out_user_id = models.CharField("Out User ID", max_length=255, blank=True, null=True, db_index=True)
     # 出货操作人姓名
     out_user_name = models.CharField("Out User Name", max_length=255, blank=True, null=True)
-    # 出货对象角色
-    out_user_role = models.CharField("Out User Role", max_length=64, blank=True, null=True)
+    # 出货操作人角色
+    out_user_role = models.CharField("Out User Role", max_length=16, blank=True, null=True)
+    # 发货单所有者
+    out_user_owner = models.CharField("Owner", max_length=16, blank=True, null=True)
     # 外仓id
     outstorage_id = models.CharField("Outstorage ID", max_length=255, blank=True, null=True, db_index=True)
     # 出货方向（Guide、CusService、OutStorage）
@@ -113,201 +117,6 @@ class Distribute(BaseModelTimeAndDeleted):
     # 发货单上的商品数量
     total_quantity = models.IntegerField('商品数量', null=True, blank=True, default=0)
 
-    # TODO: @property
-    # @property
-    # def distributelines(self):
-    #     return Distributeline.objects.filter(distribute_id=self.id)
-
-    # @property
-    # def order(self):
-    #     order_obj_list = Order.objects.filter(id=self.order_id)
-    #     order_obj = None
-    #     if order_obj_list:
-    #         order_obj = order_obj_list[0]
-    #     return order_obj
-
-    # @property
-    # def aftersale(self):
-    #     aftersale_obj_list = Afs.objects.filter(id=self.aftersale_id)
-    #     aftersale_obj = None
-    #     if aftersale_obj_list:
-    #         aftersale_obj = aftersale_obj_list[0]
-    #     return aftersale_obj
-
-    # @property
-    # def available_event_list(self):
-    #     return get_available_event_list(self.distribute_status)
-
-    # @cached_property
-    # def shipping_address(self):
-    #     if not self.shipping_address_id:
-    #         return None
-    #     return get_object_or_None(ShippingAddress, id=self.shipping_address_id)
-
-    # @property
-    # def express_order(self):
-    #     relas = ExpressRela.objects.filter(distribute_id=self.id)
-    #     if not relas:
-    #         return None
-    #     newexpressorder_id = relas[0].newexpressorder_id
-    #     exorders = NewExpressOrder.objects.filter(id=newexpressorder_id)
-    #     if not exorders:
-    #         return None
-    #     else:
-    #         return exorders[0]
-
-    # @property
-    # def customer_footprints(self):
-    #     footprints_message_list = []
-    #     footprints = FootPrint.objects.filter(distribute_id=self.id, message_level=MessageLevel.FOR_CUSTOMER).order_by("-created_time")
-    #     for footprint in footprints:
-    #         tmp_message = [str(footprint.created_time), footprint.message]
-    #         footprints_message_list.append(tmp_message)
-
-    #     relas = ExpressRela.objects.filter(distribute_id=self.id)
-    #     if not relas:
-    #         return footprints_message_list
-    #     newexpressorder_id = relas[0].newexpressorder_id
-    #     exorders = NewExpressOrder.objects.filter(id=newexpressorder_id)
-    #     if not exorders:
-    #         return footprints_message_list
-    #     tmp_express_order = exorders[0]
-    #     if not tmp_express_order:
-    #         return footprints_message_list
-
-    #     express_message_list = []
-    #     routes = None
-    #     try:
-    #         express_code = tmp_express_order.express_code
-    #         shipping_number = tmp_express_order.shipping_number
-    #         account = tmp_express_order.account
-
-    #         if account == express_pay_account.BAISHI: # 百世海淘代发
-    #             # 查询
-    #             haitaoorder_obj = get_sparrow_haitao_order_info(order_id=self.order_id)
-    #             if not haitaoorder_obj:
-    #                 raise(f"无此订单{self.order_id}")
-    #             customerCode = haitaoorder_obj.customerCode
-    #             warehouseCode = haitaoorder_obj.warehouseCode
-    #             baishi = Baishi_ShippingOrder()
-    #             result = baishi.get_express_route_info_by_distribute_number(customerCode=customerCode, warehouseCode=warehouseCode, distribute_number=self.number)
-    #             result = baishi.express_route_info_format(result)
-    #             routes = result.get('data')
-
-    #         elif express_code == ShippingPartnerCodes.YZPY:
-    #             yz = YZ_ShippingOrder()
-    #             result = yz.get_express_route_info(shipping_number)
-    #             result = yz.express_route_info_format(result)
-    #             routes = result.get('data')
-    #         elif express_code == ShippingPartnerCodes.SF:
-    #             sf = SF_ShippingOrder({"express_code": express_code})
-    #             xml_res = sf.get_express_route_info([shipping_number])
-    #             result = sf.parse_express_route_info(xml_res)
-    #             result = sf.express_route_info_format(result)
-    #             routes = result.get(shipping_number, {}).get('data')
-    #         else:
-    #             kuaidi100 = get_kuaidi100_object()
-    #             result = kuaidi100.get_route_info(express_code, shipping_number)
-    #             routes = result.get("data", None)
-
-    #         if not routes:
-    #             return footprints_message_list
-
-    #         for route in routes:
-    #             if not route:
-    #                 continue
-    #             created_time = route.get("time", None)
-    #             message = route.get("context", "")
-    #             tmp_message = [created_time, message]
-    #             express_message_list.append(tmp_message)
-
-    #     except BaseException as be:
-    #         err_msg = "customer_footprints: "+str(be)
-    #         logger.error(err_msg, exc_info=True)
-    #         express_message_list = []
-
-    #     footprints = express_message_list + footprints_message_list
-    #     return footprints
-
-    # @property
-    # def cusservice_footprints(self):
-    #     footprints = FootPrint.objects.filter(distribute_id=self.id)
-    #     return footprints
-
-    # @property
-    # def express_routes(self):
-
-    #     footprints_message_list =[]
-    #     relas = ExpressRela.objects.filter(distribute_id=self.id)
-    #     if not relas:
-    #         return footprints_message_list
-    #     newexpressorder_id = relas[0].newexpressorder_id
-    #     exorders = NewExpressOrder.objects.filter(id=newexpressorder_id)
-    #     if not exorders:
-    #         return footprints_message_list
-    #     tmp_express_order = exorders[0]
-    #     if not tmp_express_order:
-    #         return footprints_message_list
-
-    #     express_message_list = []
-    #     routes = None
-    #     try:
-    #         express_code = tmp_express_order.express_code
-    #         shipping_number = tmp_express_order.shipping_number
-    #         account = tmp_express_order.account
-
-    #         if account == express_pay_account.BAISHI: # 百世海淘代发
-    #             haitaoorder_obj = get_sparrow_haitao_order_info(order_id=self.order_id)
-    #             if not haitaoorder_obj:
-    #                 raise(f"无此订单{self.order_id}")
-    #             customerCode = haitaoorder_obj.customerCode
-    #             warehouseCode = haitaoorder_obj.warehouseCode
-    #             baishi = Baishi_ShippingOrder()
-    #             result = baishi.get_express_route_info_by_distribute_number(customerCode=customerCode, warehouseCode=warehouseCode, distribute_number=self.id)
-    #             result = baishi.express_route_info_format(result)
-    #             routes = result.get('data')
-
-    #         elif express_code == ShippingPartnerCodes.YZPY:
-    #             yz = YZ_ShippingOrder()
-    #             result = yz.get_express_route_info(shipping_number)
-    #             result = yz.express_route_info_format(result)
-    #             routes = result.get('data')
-
-    #         elif express_code == ShippingPartnerCodes.SF:
-    #             sf = SF_ShippingOrder({"express_code": express_code})
-    #             xml_res = sf.get_express_route_info([shipping_number])
-    #             result = sf.parse_express_route_info(xml_res)
-    #             result = sf.express_route_info_format(result)
-    #             routes = result.get(shipping_number, {}).get('data')
-    #         else:
-    #             kuaidi100 = get_kuaidi100_object()
-
-    #             result = kuaidi100.get_route_info(express_code, shipping_number)
-    #             routes = result.get("data", None)
-
-    #         if not routes:
-    #             return footprints_message_list
-
-    #         for route in routes:
-    #             if not route:
-    #                 continue
-    #             created_time = route.get("time", None)
-    #             message = route.get("context", "")
-    #             tmp_message = {"time":created_time, "context":message}
-    #             express_message_list.append(tmp_message)
-
-    #     except BaseException as be:
-    #         err_msg = "customer_footprints: "+str(be)
-    #         logger.error(err_msg, exc_info=True)
-    #         express_message_list = []
-
-    #     footprints = express_message_list + footprints_message_list
-    #     return footprints
-
-    # @property
-    # def ex_status_for_b(self):
-    #     return int(self.if_need_exchange) + int(self.exchange_status)
-
     class Meta:
         app_label = APP_LABEL
         ordering = ['-created_time']
@@ -423,6 +232,8 @@ class FootPrint(BaseModelTimeAndDeleted):
     event_sponsor = models.CharField('事件发起人', max_length=255, blank=True, null=True)
     # event_sponsor_name（事件发起人昵称）
     event_sponsor_name = models.CharField('事件发起人昵称', max_length=255, blank=True, null=True)
+    # event_sponsor_role (事件发起人角色)
+    event_sponsor_role = models.CharField('事件发起人角色', max_length=16, blank=True, null=True)
     # event_time(事件发生时间)
     event_time = models.DateTimeField("Event Happened Time", blank=True, null=True, auto_now=True)
     # from_status(起始状态)
@@ -537,8 +348,12 @@ class EventPool(BaseModelTimeAndDeleted):
     number = models.CharField("Event Pool number", max_length=128, blank=True, null=True, db_index=True, unique=True)
     # login_user_id 登录人ID
     login_user_id = models.CharField('登录人ID', max_length=255, blank=True, null=True)
+    # login_user_role 登录人角色
+    login_user_role = models.CharField('登录人角色', max_length=16, blank=True, null=True)
     # creator_id 创建人ID
-    creator_id = models.CharField('创建人ID', max_length=255, blank=True, null=True, db_index=True)
+    creator_id = models.CharField('创建人ID', max_length=40, blank=True, null=True, db_index=True)
+    # creator_role 创建人角色
+    creator_role = models.CharField('创建人角色', max_length=16, blank=True, null=True, db_index=True)
     # creator_username 创建人手机号
     creator_username = models.CharField('创建人手机号', max_length=15, help_text=u'创建人手机号', blank=True, null=True)
     # creator_displayname 创建人昵称
@@ -645,6 +460,7 @@ class UserShipReminderSum(BaseModelTimeAndDeleted):
         app_label = APP_LABEL
         ordering = ['-created_time']
 
+
 class UserShipReminderDetail(BaseModelTimeAndDeleted):
     '''
     客户发货提醒明细
@@ -662,4 +478,79 @@ class UserShipReminderDetail(BaseModelTimeAndDeleted):
 
     class Meta:
         app_label = APP_LABEL
-        ordering = ['-created_time']
\ No newline at end of file
+        ordering = ['-created_time']
+
+
+class UserOptCount(BaseModelTimeAndDeleted):
+
+    opt_user_id = models.CharField('User ID', max_length=40, db_index=True)
+    # opt_username 操作员手机号
+    opt_username = models.CharField('操作员手机号', max_length=15, help_text=u'操作员手机号', blank=True, null=True)
+    # opt_displayname 操作员姓名
+    opt_displayname = models.CharField("操作员姓名", max_length=10, blank=True, null=True)
+    # opt_user_role 操作员角色
+    opt_user_role = models.CharField("操作员橘色", max_length=15, blank=True, null=True)
+    # event_code 事件编码
+    event_code = models.CharField("事件编码", max_length=36, db_index=True)
+    # event_name 事件名称
+    event_name = models.CharField("事件名称", max_length=36)
+    # event_day 发生日
+    event_day = models.DateField(blank=True, null=True, auto_now=True)
+    # opt_times 操作次数
+    opt_times = models.PositiveIntegerField("操作次数", default=0)
+    # shop_id 专柜id
+    shop_id = models.PositiveIntegerField('Shop ID', blank=True, null=True, db_index=True)
+    # shop_name 专柜号
+    shop_name = models.CharField("Shop Name", max_length=36, blank=True)
+    # shop_num(专柜号)
+    shop_num = models.CharField("Shop number", max_length=12, blank=True)
+
+    class Meta:
+        app_label = APP_LABEL
+        ordering = ['-created_time']
+        # 联合约束
+        unique_together = ["opt_user_id", "event_day", "event_code", "shop_id"]
+
+    def __str__(self):
+        return f'{self.opt_username}-{self.opt_displayname}-{self.event_code}-{self.event_day}-{self.shop_name}'
+
+
+class UserOptDetail(BaseModelTimeAndDeleted):
+    opt_user_id = models.CharField('User ID', max_length=40, db_index=True)
+    # opt_username 操作员手机号
+    opt_username = models.CharField('操作员手机号', max_length=15, help_text=u'操作员手机号', blank=True, null=True)
+    # opt_displayname 操作员姓名
+    opt_displayname = models.CharField("操作员姓名", max_length=10, blank=True, null=True)
+    # opt_user_role 操作员角色
+    opt_user_role = models.CharField("操作员橘色", max_length=15, blank=True, null=True)
+    # event_code 事件编码
+    event_code = models.CharField("事件编码", max_length=36, db_index=True)
+    # event_name 事件名称
+    event_name = models.CharField("事件名称", max_length=36)
+    # event_day 发生日
+    event_day = models.DateField(blank=True, null=True, auto_now=True)
+    # opt_times 操作次数
+    opt_times = models.PositiveIntegerField("操作次数", default=0)
+    # shop_id 专柜id
+    shop_id = models.PositiveIntegerField('Shop ID', blank=True, null=True, db_index=True)
+    # shop_name 专柜号
+    shop_name = models.CharField("Shop Name", max_length=36, blank=True)
+    # shop_num 专柜号
+    shop_num = models.CharField("Shop number", max_length=12, blank=True)
+    # distribute_id 发货单id
+    distribute_id = models.CharField('Distribute ID', max_length=40, blank=True, null=True, db_index=True)
+    # distribute_number 发货单号
+    distribute_number = models.CharField("Distribute Number", max_length=40)
+    # from_status(起始状态)
+    from_status = models.CharField('起始状态', max_length=24, blank=True, null=True, db_index=True)
+    # to_status(结果状态)
+    to_status = models.CharField('结果状态', max_length=24, blank=True, null=True, db_index=True)
+    # 运单号
+    shipping_number = models.CharField("快递单号/母单号", max_length=64, blank=True, null=True)
+
+    class Meta:
+        app_label = APP_LABEL
+        ordering = ['-created_time']
+
+    def __str__(self):
+        return f'{self.opt_username}-{self.opt_displayname}-{self.event_code}-{self.event_day}-{self.shop_name}'
